@@ -9,7 +9,7 @@ use Data::Clone;
 use List::Util qw(min max);
 use Scalar::Util qw(looks_like_number);
 
-our $VERSION = '0.13'; # VERSION
+our $VERSION = '0.14'; # VERSION
 
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(
@@ -424,7 +424,7 @@ Perinci::Examples - Example modules containing metadata and various example func
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -437,10 +437,17 @@ This module and its submodules contain an odd mix of various functions,
 variables, and other code entities, along with their L<Rinci> metadata. Mostly
 used for testing Rinci specification and the various L<Perinci> modules.
 
+Example scripts are put in a separate distribution (see
+L<Perinci::Examples::Bin>) to make dependencies for this distribution minimal
+(e.g. not depending on L<Perinci::CmdLine>) since this example module(s) are
+usually used in the tests of other modules.
+
 =head1 SEE ALSO
 
 L<Perinci>
 
+L<Perinci::Examples::Bin>
+
 =head1 DESCRIPTION
 
 
